﻿package {
	
	import flash.display.Sprite;
	import flash.geom.Point;
	import flash.events.Event;
	import flash.net.URLLoader
	import flash.net.URLRequest;
	import com.google.maps.Map;
	import com.google.maps.MapType;
	import com.google.maps.MapEvent;
	import com.google.maps.LatLng;
	import com.google.maps.LatLngBounds;
	import com.google.maps.overlays.Marker;
	import com.google.maps.controls.MapTypeControl;
	import com.google.maps.controls.ZoomControl;
	import com.google.maps.controls.PositionControl;
	import com.google.maps.controls.ScaleControl;
	import com.google.maps.controls.ControlBase;
	import com.google.maps.controls.OverviewMapControl;
	
	public class Main extends Sprite {
		
		const FLICKR_URL:String = "http://api.flickr.com/services/rest/";	//Flickr API URL
		const FLICKR_API_KEY:String = "";	//Flickr API Keyを記述
		const GOOGLE_API_KEY:String = "";	//Google Maps API Keyを記述
		var googleMaps:Map;	//マップオブジェクト
		
		//コンストラクタ
		public function Main() {
			initMap();
		}
		
		//Google Maps 作成
		function initMap():void {
			//マップ生成
			googleMaps = new Map();
			//基本設定
			googleMaps.key = GOOGLE_API_KEY;	//APIキー登録
			googleMaps.language = "ja";	//言語
			googleMaps.setSize(new Point(stage.stageWidth, stage.stageHeight));	//マップサイズ
			//コントロール表示
			googleMaps.addControl(new PositionControl());		//ポジションコントロールを表示
			googleMaps.addControl(new ZoomControl());			//ズームコントロールを表示
			googleMaps.addControl(new MapTypeControl());		//マップタイプコントロールを表示
			googleMaps.addControl(new OverviewMapControl());	//概要マップの表示
			googleMaps.addControl(new ScaleControl());			//距離の表示
			//イベント設定
			googleMaps.addEventListener(MapEvent.MAP_READY, onMapReady);
			//配置
			addChild(googleMaps);
		}
		
		//地図生成完了
		function onMapReady(event:MapEvent):void {
			//初期表示設定
			googleMaps.setCenter(new LatLng(35.691143,139.740772), 16, MapType.NORMAL_MAP_TYPE);
			//操作設定
			googleMaps.enableScrollWheelZoom();		//スクロールホイールでのズーム許可
			googleMaps.enableContinuousZoom();		//連続ズームの許可
			googleMaps.enableControlByKeyboard();	//キーボードによるマップ操作の許可
			//イベントリスナーを削除
			googleMaps.removeEventListener(MapEvent.MAP_READY, onMapReady);
			//Flickr API 処理
			initFlickrApi();
		}
		
		//Flickr API 処理
		function initFlickrApi():void {
			//URLLoader作成
			var apiUrl = new URLRequest(getUrl());
			var apiLoader:URLLoader = new URLLoader(apiUrl);
			//イベント設定
			apiLoader.addEventListener(Event.COMPLETE, apiLoaderComplete);
			//読み込み開始
			apiLoader.load(apiUrl);
		}
		
		//Flickr API URL 生成
		function getUrl():String {
			var urlStr:String = FLICKR_URL;
			var w:String = googleMaps.getLatLngBounds().getWest().toString();
			var s:String = googleMaps.getLatLngBounds().getSouth().toString();
			var e:String = googleMaps.getLatLngBounds().getEast().toString();
			var n:String = googleMaps.getLatLngBounds().getNorth().toString();
			urlStr += "?api_key=" + FLICKR_API_KEY;
			urlStr += "&method=" + "flickr.photos.search";
			urlStr += "&bbox=" + w + "," + s + "," + e + "," + n;	//検索範囲
			urlStr += "&license=" + "4";
			urlStr += "&extras=" + "geo,date_taken,owner_name";
			urlStr += "&per_page=" + "100";
			return urlStr;
		}
		
		//Flickr API 読み込み完了
		function apiLoaderComplete(event:Event):void {
			//データを格納
			var xmlData:XML = new XML(event.target.data);
			//写真数を取得
			var photoCount:uint = xmlData.photos[0].@total * 1;
			//XML処理
			for (var i = 0; i < photoCount; i++) {
				//座標
				var x:Number = xmlData.photos[0].photo[i].@latitude * 1;
				var y:Number = xmlData.photos[0].photo[i].@longitude * 1;
				//Photoマーカー生成
				var marker:PhotoMarker = new PhotoMarker(new LatLng(x, y), googleMaps);
				//情報を保持
				marker.title = xmlData.photos[0].photo[i].@title;
				marker.farm = xmlData.photos[0].photo[i].@farm;
				marker.server = xmlData.photos[0].photo[i].@server;
				marker.id = xmlData.photos[0].photo[i].@id;
				marker.secret = xmlData.photos[0].photo[i].@secret;
				marker.owner = xmlData.photos[0].photo[i].@owner;
				marker.ownerName = xmlData.photos[0].photo[i].@ownername;
				marker.datetaken = xmlData.photos[0].photo[i].@datetaken;
				//写真の読み込み処理を開始
				marker.imgLoad();
				//マーカー配置
				googleMaps.addOverlay(marker);
			}
		}
	}
}


